@@ -209,7 +209,12 @@ utils::globalVariables(
     "mean...summary",
     "mean.conf.low...summary",
     "mean.conf.high...summary",
-    "n...summary"
+    "n...summary",
+    "angle",
+    "vjust",
+    "x_pos",
+    "y_pos",
+    "label.value"
   ),
   package = "ggstatsplot",
   add = FALSE
