@@ -19,40 +19,19 @@ testthat::test_that(
         xlab = "sleep (total)",
         ylab = "body weight",
         type = "p",
+        xfill = "red",
+        yfill = "orange",
         messages = TRUE,
-        centrality.para = "mean",
+        centrality.parameter = "mean",
         marginal = FALSE,
         bf.message = TRUE,
         caption = "ggplot2 dataset",
-        title = "Mammalian sleep",
-        xfill = NULL,
-        package = "wesanderson",
-        palette = "BottleRocket1"
+        title = "Mammalian sleep"
       )
 
     # plot build
     pb <- ggplot2::ggplot_build(p)
 
-    # checking data used to create a plot
-    dat <- tibble::as_tibble(p$data) %>%
-      dplyr::mutate_if(
-        .tbl = .,
-        .predicate = is.factor,
-        .funs = ~ as.character(.)
-      )
-
-    # checking dimensions of data
-    data_dims <- dim(dat)
-    ggrepel_dims <- dim(p$plot_env$label_data)
-
-    # testing everything is okay with imported and ggrepel data
-    testthat::expect_equal(data_dims, c(83L, 11L))
-    testthat::expect_equal(
-      ggrepel_dims[1],
-      dim(dplyr::filter(ggplot2::msleep, bodywt > 2000))[1]
-    )
-    testthat::expect_equal(ggrepel_dims[2], 11L)
-
     # checking layer data
     testthat::expect_equal(length(pb$data), 7L)
     testthat::expect_equal(dim(pb$data[[1]]), c(83L, 10L))
@@ -61,21 +40,67 @@ testthat::test_that(
     testthat::expect_equal(dim(pb$data[[4]]), c(1L, 7L))
     testthat::expect_equal(dim(pb$data[[5]]), c(83L, 15L))
     testthat::expect_equal(dim(pb$data[[6]]), c(83L, 15L))
-    # testthat::expect_equal(dim(pb$data[[7]]), c(2L, 15L))
 
     # checking intercepts
-    testthat::expect_equal(pb$data[[3]]$xintercept, 10.43373, tolerance = 0.001)
-    testthat::expect_equal(pb$data[[4]]$yintercept, 166.1363, tolerance = 0.001)
-    testthat::expect_equal(unclass(pb$data[[3]]$colour), "#A42820FF")
-    testthat::expect_equal(unclass(pb$data[[4]]$colour), "#5F5647FF")
+    testthat::expect_equal(
+      pb$data[[3]],
+      structure(
+        list(
+          xintercept = 10.433734939759,
+          PANEL = structure(1L, .Label = "1", class = "factor"),
+          group = -1L,
+          colour = "red",
+          size = 1,
+          linetype = "dashed",
+          alpha = NA
+        ),
+        row.names = c(NA, -1L),
+        class = "data.frame"
+      )
+    )
+
+    testthat::expect_equal(
+      pb$data[[4]],
+      structure(
+        list(
+          yintercept = 166.13634939759,
+          PANEL = structure(1L, .Label = "1", class = "factor"),
+          group = -1L,
+          colour = "orange",
+          size = 1,
+          linetype = "dashed",
+          alpha = NA
+        ),
+        row.names = c(NA, -1L),
+        class = "data.frame"
+      )
+    )
+
+    testthat::expect_equal(
+      pb$data[[7]],
+      structure(
+        list(
+          x = c(3.9, 3.3),
+          y = c(2547, 6654),
+          label = c("Asian elephant", "African elephant"),
+          PANEL = structure(c(1L, 1L), class = "factor", .Label = "1"),
+          group = c(-1L, -1L),
+          colour = c("black", "black"),
+          fill = c("white", "white"),
+          size = c(3, 3),
+          angle = c(0, 0),
+          alpha = c(NA, NA),
+          family = c("", ""),
+          fontface = c(1, 1),
+          lineheight = c(1.2, 1.2),
+          hjust = c(0.5, 0.5),
+          vjust = c(0.5, 0.5)
+        ),
+        row.names = c(NA, -2L),
+        class = "data.frame"
+      )
+    )
 
-    # check labels
-    testthat::expect_equal(p$plot_env$x_label_pos, 10.88401, tolerance = 0.002)
-    testthat::expect_equal(p$plot_env$x_median, 10.1000, tolerance = 0.002)
-    testthat::expect_equal(p$plot_env$x_mean, 10.43373, tolerance = 0.002)
-    testthat::expect_equal(p$plot_env$y_label_pos, 2954.955, tolerance = 0.002)
-    testthat::expect_equal(p$plot_env$y_median, 1.6700, tolerance = 0.002)
-    testthat::expect_equal(p$plot_env$y_mean, 166.1363, tolerance = 0.002)
 
     # checking geoms
     testthat::expect_equal(
@@ -157,7 +182,7 @@ testthat::test_that(
         data = ggplot2::msleep,
         x = sleep_total,
         y = bodywt,
-        centrality.para = FALSE,
+        centrality.parameter = "none",
         type = "np",
         conf.level = 0.99,
         marginal = FALSE,
@@ -169,14 +194,15 @@ testthat::test_that(
 
     # subtitle
     set.seed(123)
-    p_subtitle <- statsExpressions::expr_corr_test(
-      data = ggplot2::msleep,
-      x = sleep_total,
-      y = bodywt,
-      type = "np",
-      conf.level = 0.99,
-      messages = FALSE
-    )
+    p_subtitle <-
+      statsExpressions::expr_corr_test(
+        data = ggplot2::msleep,
+        x = sleep_total,
+        y = bodywt,
+        type = "np",
+        conf.level = 0.99,
+        messages = FALSE
+      )
 
     # testing data and annotations
     testthat::expect_equal(length(pb$data), 2L)
@@ -201,10 +227,9 @@ testthat::test_that(
         x = sleep_total,
         y = bodywt,
         type = "r",
-        centrality.para = "mean",
+        centrality.parameter = "mean",
         conf.level = 0.90,
-        point.color = "red",
-        point.size = 5,
+        point.args = list(color = "red", size = 5),
         point.height.jitter = 0.40,
         point.width.jitter = 0.20,
         marginal = FALSE,
@@ -261,13 +286,9 @@ testthat::test_that(
         data = ggplot2::msleep,
         x = sleep_cycle,
         y = awake,
-        xfill = NULL,
-        palette = "Royal1",
-        package = "wesanderson",
         marginal = FALSE,
         bf.message = FALSE,
-        centrality.para = "median",
-        axes.range.restrict = TRUE,
+        centrality.parameter = "median",
         ggplot.component = ggplot2::scale_y_continuous(breaks = seq(0, 20, 2)),
         messages = FALSE
       )
@@ -276,19 +297,23 @@ testthat::test_that(
     pb <- ggplot2::ggplot_build(p)
 
     # checking intercepts
-    testthat::expect_equal(pb$plot$plot_env$x_label_pos,
+    testthat::expect_equal(
+      pb$plot$plot_env$x_label_pos,
       0.8083333,
       tolerance = 1e-3
     )
-    testthat::expect_equal(pb$plot$plot_env$y_label_pos,
+    testthat::expect_equal(
+      pb$plot$plot_env$y_label_pos,
       13.39839,
       tolerance = 1e-3
     )
-    testthat::expect_equal(pb$data[[3]]$xintercept[[1]],
+    testthat::expect_equal(
+      pb$data[[3]]$xintercept[[1]],
       median(ggplot2::msleep$sleep_cycle, na.rm = TRUE),
       tolerance = 1e-3
     )
-    testthat::expect_equal(pb$data[[4]]$yintercept[[1]],
+    testthat::expect_equal(
+      pb$data[[4]]$yintercept[[1]],
       median(ggplot2::msleep$awake, na.rm = TRUE),
       tolerance = 1e-3
     )
@@ -303,7 +328,7 @@ testthat::test_that(
       c("0.4", "0.8", "1.2")
     )
     testthat::expect_equal(pb$layout$panel_params[[1]]$y.range,
-      c(3.25, 21.95),
+      c(3.17, 23.63),
       tolerance = 0.001
     )
     testthat::expect_identical(
@@ -338,13 +363,14 @@ testthat::test_that(
       )
 
     # subtitle
-    p_subtitle <- statsExpressions::expr_corr_test(
-      data = ggplot2::msleep,
-      x = sleep_total,
-      y = bodywt,
-      type = "bf",
-      messages = FALSE
-    )
+    p_subtitle <-
+      statsExpressions::expr_corr_test(
+        data = ggplot2::msleep,
+        x = sleep_total,
+        y = bodywt,
+        type = "bf",
+        messages = FALSE
+      )
 
     testthat::expect_identical(class(p)[[1]], "ggExtraPlot")
     testthat::expect_identical(
@@ -379,16 +405,18 @@ testthat::test_that(
 
     # creating the plot
     set.seed(123)
-    p <- ggstatsplot::ggscatterstats(
-      data = ggplot2::msleep,
-      x = sleep_total,
-      y = sleep_cycle,
-      label.expression = "sleep_total > 17",
-      label.var = "order",
-      results.subtitle = FALSE,
-      marginal = FALSE,
-      messages = TRUE
-    ) +
+    p <-
+      ggstatsplot::ggscatterstats(
+        data = ggplot2::msleep,
+        x = sleep_total,
+        y = sleep_cycle,
+        label.expression = "sleep_total > 17",
+        label.var = "order",
+        point.label.args = list(size = 4, color = "blue", alpha = 0.5),
+        results.subtitle = FALSE,
+        marginal = FALSE,
+        messages = TRUE
+      ) +
       ggplot2::coord_cartesian(ylim = c(0, 7000)) +
       ggplot2::scale_y_continuous(breaks = seq(0, 7000, 1000))
 
@@ -400,8 +428,33 @@ testthat::test_that(
       c("0", "1000", "2000", "3000", "4000", "5000", "6000", "7000")
     )
 
+    testthat::expect_equal(
+      pb$data[[3]],
+      structure(
+        list(
+          y = c(0.383333333, 0.333333333, 0.116666667, 0.2),
+          x = c(17.4, 18, 19.7, 19.9),
+          label = c("Cingulata", "Didelphimorphia", "Chiroptera", "Chiroptera"),
+          PANEL = structure(c(1L, 1L, 1L, 1L), class = "factor", .Label = "1"),
+          group = c(-1L, -1L, -1L, -1L),
+          colour = c("blue", "blue", "blue", "blue"),
+          fill = c("white", "white", "white", "white"),
+          size = c(4, 4, 4, 4),
+          angle = c(0, 0, 0, 0),
+          alpha = c(0.5, 0.5, 0.5, 0.5),
+          family = c("", "", "", ""),
+          fontface = c(1, 1, 1, 1),
+          lineheight = c(1.2, 1.2, 1.2, 1.2),
+          hjust = c(0.5, 0.5, 0.5, 0.5),
+          vjust = c(0.5, 0.5, 0.5, 0.5)
+        ),
+        row.names = c(NA, -4L),
+        class = "data.frame"
+      )
+    )
+
     # both quoted
-    testthat::expect_true(inherits(p, what = "gg"))
+    testthat::expect_is(p, "gg")
   }
 )
 
@@ -442,36 +495,6 @@ testthat::test_that(
       what = "gg"
     ))
 
-    # one unquoted, one quoted
-    testthat::expect_true(inherits(
-      ggstatsplot::ggscatterstats(
-        data = ggplot2::msleep,
-        x = sleep_total,
-        y = sleep_cycle,
-        label.expression = sleep_total > 17,
-        label.var = "order",
-        results.subtitle = FALSE,
-        marginal = FALSE,
-        messages = TRUE
-      ),
-      what = "gg"
-    ))
-
-    # one unquoted, one quoted
-    testthat::expect_true(inherits(
-      ggstatsplot::ggscatterstats(
-        data = ggplot2::msleep,
-        x = sleep_total,
-        y = sleep_cycle,
-        label.expression = "sleep_total > 17",
-        label.var = order,
-        results.subtitle = FALSE,
-        marginal = FALSE,
-        messages = TRUE
-      ),
-      what = "gg"
-    ))
-
     # label.expression not specified
     testthat::expect_true(inherits(
       ggstatsplot::ggscatterstats(
@@ -498,43 +521,18 @@ testthat::test_that(
 
     # creating the plot
     set.seed(123)
-    p1 <-
-      ggstatsplot::ggscatterstats(
-        data = ggplot2::msleep,
-        x = sleep_total,
-        y = bodywt,
-        margins = "both",
-        messages = TRUE
-      )
-
-    p2 <-
-      ggstatsplot::ggscatterstats(
-        data = ggplot2::msleep,
-        x = sleep_total,
-        y = bodywt,
-        margins = "x",
-        messages = TRUE
-      )
-
-    p3 <-
+    p <-
       ggstatsplot::ggscatterstats(
         data = ggplot2::msleep,
         x = sleep_total,
         y = bodywt,
         margins = "y",
+        results.subtitle = FALSE,
         messages = TRUE
       )
 
     testthat::expect_identical(
-      class(p1),
-      c("ggExtraPlot", "gtable", "gTree", "grob", "gDesc")
-    )
-    testthat::expect_identical(
-      class(p2),
-      c("ggExtraPlot", "gtable", "gTree", "grob", "gDesc")
-    )
-    testthat::expect_identical(
-      class(p3),
+      class(p),
       c("ggExtraPlot", "gtable", "gTree", "grob", "gDesc")
     )
   }
@@ -549,36 +547,41 @@ testthat::test_that(
 
     # creating the messages
     set.seed(123)
-    p1 <- ggstatsplot::ggscatterstats(
-      data = dplyr::starwars,
-      x = mass,
-      y = height,
-      formula = y ~ log(x),
-      method = stats::lm,
-      marginal = FALSE
-    )
+    p1 <-
+      ggstatsplot::ggscatterstats(
+        data = dplyr::starwars,
+        x = mass,
+        y = height,
+        formula = y ~ log(x),
+        method = stats::lm,
+        marginal = FALSE
+      )
 
     set.seed(123)
-    p2 <- ggstatsplot::ggscatterstats(
-      data = dplyr::starwars,
-      x = mass,
-      y = height,
-      method = "gam",
-      marginal = FALSE
-    )
+    p2 <-
+      ggstatsplot::ggscatterstats(
+        data = dplyr::starwars,
+        x = mass,
+        y = height,
+        results.subtitle = TRUE,
+        method = "gam",
+        marginal = FALSE
+      )
 
-    p3 <- suppressWarnings(ggstatsplot::ggscatterstats(
-      data = dplyr::starwars,
-      x = mass,
-      y = height,
-      method = MASS::rlm,
-      marginal = FALSE
-    ))
+    p3 <-
+      ggstatsplot::ggscatterstats(
+        data = dplyr::starwars,
+        x = mass,
+        y = height,
+        results.subtitle = TRUE,
+        method = MASS::rlm,
+        marginal = FALSE
+      )
 
     # build the plot
     pb1 <- ggplot2::ggplot_build(p1)
     pb2 <- ggplot2::ggplot_build(p2)
-    pb3 <- suppressWarnings(ggplot2::ggplot_build(p3))
+    pb3 <- ggplot2::ggplot_build(p3)
 
     # checking subtitle - lack thereof
     testthat::expect_null(pb1$plot$labels$subtitle, NULL)
@@ -594,15 +597,19 @@ testthat::test_that(
       as.character(deparse(pb2$plot$layers[[2]]$stat_params$formula)),
       "y ~ x"
     )
-
+    testthat::expect_identical(
+      as.character(deparse(pb3$plot$layers[[2]]$stat_params$formula)),
+      "y ~ x"
+    )
     testthat::expect_null(pb3$plot$labels$subtitle, NULL)
+    testthat::expect_is(pb3$plot$layers[[2]]$stat_params$method, "function")
   }
 )
 
-# subtitle return ----------------------------------------------------------
+# subtitle output ----------------------------------------------------------
 
 testthat::test_that(
-  desc = "subtitle return",
+  desc = "subtitle output",
   code = {
     testthat::skip_on_cran()
 
@@ -615,7 +622,7 @@ testthat::test_that(
         y = height,
         conf.level = 0.90,
         type = "r",
-        return = "subtitle",
+        output = "subtitle",
         messages = FALSE
       )
 
@@ -653,32 +660,3 @@ testthat::test_that(
     )
   }
 )
-
-
-# message checks ----------------------------------------------------------
-
-testthat::test_that(
-  desc = "message checks",
-  code = {
-    testthat::skip_on_cran()
-
-    # creating the messages
-    p_message1 <-
-      capture.output(
-        ggstatsplot::ggscatterstats(
-          data = dplyr::starwars,
-          x = mass,
-          y = height,
-          conf.level = 0.90,
-          nboot = 15,
-          type = "r"
-        )
-      )
-
-    # checking captured messages
-    testthat::expect_match(p_message1[1],
-      "90% CI for effect size estimate was computed with 15",
-      fixed = TRUE
-    )
-  }
-)
