@@ -1,5 +1,3 @@
-context(desc = "ggwithinstats")
-
 # for t-test
 data_bugs_2 <- ggstatsplot::bugs_long %>%
   dplyr::filter(.data = ., condition %in% c("HDLF", "HDHF"))
@@ -13,40 +11,43 @@ testthat::test_that(
 
     # plot
     set.seed(123)
-    p1 <- ggstatsplot::ggwithinstats(
-      data = data_bugs_2,
-      x = condition,
-      y = desire,
-      type = "bayes",
-      sort = "descending",
-      sort.fun = mean,
-      k = 4,
-      conf.level = 0.99,
-      outlier.tagging = TRUE,
-      outlier.label = "region",
-      outlier.coef = 1.5,
-      bf.message = TRUE,
-      pairwise.comparisons = TRUE,
-      pairwise.annotation = "asterisk",
-      title = "bugs dataset",
-      caption = "From `jmv` package",
-      messages = FALSE
-    )
+    p1 <-
+      ggstatsplot::ggwithinstats(
+        data = data_bugs_2,
+        x = condition,
+        y = desire,
+        type = "bayes",
+        k = 4,
+        conf.level = 0.99,
+        outlier.tagging = TRUE,
+        outlier.label = "region",
+        outlier.coef = 1.5,
+        bf.message = TRUE,
+        pairwise.comparisons = TRUE,
+        pairwise.annotation = "asterisk",
+        point.path.args = list(color = "red"),
+        mean.path.args = list(color = "blue", size = 2, alpha = 0.8),
+        mean.point.args = list(size = 3, color = "darkgreen", alpha = 0.5),
+        title = "bugs dataset",
+        caption = "From `jmv` package",
+        messages = FALSE
+      )
 
     # build the plot
     pb1 <- ggplot2::ggplot_build(p1)
 
     # subtitle
     set.seed(123)
-    p1_subtitle <- statsExpressions::expr_t_bayes(
-      data = data_bugs_2,
-      x = condition,
-      y = desire,
-      k = 4,
-      paired = TRUE,
-      conf.level = 0.99,
-      messages = FALSE
-    )
+    p1_subtitle <-
+      statsExpressions::expr_t_bayes(
+        data = data_bugs_2,
+        x = condition,
+        y = desire,
+        k = 4,
+        paired = TRUE,
+        conf.level = 0.99,
+        messages = FALSE
+      )
 
     # dataframe used for visualization
     testthat::expect_equal(length(pb1$data), 8L)
@@ -57,9 +58,139 @@ testthat::test_that(
     testthat::expect_equal(dim(pb1$data[[4]]), c(180L, 8L))
     testthat::expect_equal(dim(pb1$data[[5]]), c(0L, 0L))
     testthat::expect_equal(dim(pb1$data[[6]]), c(2L, 12L))
-    # testthat::expect_equal(dim(pb1$data[[7]]), c(2L, 15L))
     testthat::expect_equal(dim(pb1$data[[8]]), c(2L, 8L))
 
+    # checking geom data
+    testthat::expect_identical(pb1$data[[4]]$colour[[1]], "red")
+    testthat::expect_equal(pb1$data[[4]]$linetype[[1]], 1)
+    testthat::expect_equal(pb1$data[[4]]$size[[1]], 0.5)
+    testthat::expect_equal(
+      pb1$data[[2]],
+      structure(
+        list(
+          ymin = c(0, 0),
+          lower = c(6, 4.5),
+          middle = c(8.75, 8),
+          upper = c(10, 9.5),
+          ymax = c(10, 10),
+          outliers = list(numeric(0), numeric(0)),
+          notchupper = c(9.41618649374214, 8.83273311717767),
+          notchlower = c(8.08381350625786, 7.16726688282233),
+          x = c(1, 2),
+          PANEL = structure(c(1L, 1L), .Label = "1", class = "factor"),
+          group = 1:2,
+          ymin_final = c(0, 0),
+          ymax_final = c(10, 10),
+          xmin = c(0.9, 1.9),
+          xmax = c(1.1, 2.1),
+          xid = c(1, 2),
+          newx = c(1, 2),
+          new_width = c(0.2, 0.2),
+          weight = c(1, 1),
+          colour = c("grey20", "grey20"),
+          fill = c("white", "white"),
+          size = c(0.5, 0.5),
+          alpha = c(0.5, 0.5),
+          shape = c(19, 19),
+          linetype = c("solid", "solid")
+        ),
+        row.names = c(NA, -2L),
+        class = "data.frame"
+      )
+    )
+
+    testthat::expect_equal(
+      pb1$data[[6]],
+      structure(
+        list(
+          x = 1:2,
+          group = 1:2,
+          y = c(
+            7.86666666666667,
+            6.73888888888889
+          ),
+          ymin = c(NA_real_, NA_real_),
+          ymax = c(
+            NA_real_,
+            NA_real_
+          ),
+          PANEL = structure(c(1L, 1L), .Label = "1", class = "factor"),
+          shape = c(19, 19),
+          colour = c("darkgreen", "darkgreen"),
+          size = c(3, 3),
+          fill = c(NA, NA),
+          alpha = c(0.5, 0.5),
+          stroke = c(
+            0.5,
+            0.5
+          )
+        ),
+        row.names = c(NA, -2L),
+        class = "data.frame"
+      )
+    )
+
+    testthat::expect_equal(
+      pb1$data[[7]],
+      structure(
+        list(
+          x = 1:2,
+          y = c(7.86666666666667, 6.73888888888889),
+          label = c(
+            "list(~italic(widehat(mu))== 7.8667 )",
+            "list(~italic(widehat(mu))== 6.7389 )"
+          ),
+          PANEL = structure(c(1L, 1L), class = "factor", .Label = "1"),
+          group = structure(1:2, n = 2L),
+          colour = c("black", "black"),
+          fill = c("white", "white"),
+          size = c(3, 3),
+          angle = c(
+            0,
+            0
+          ),
+          alpha = c(NA, NA),
+          family = c("", ""),
+          fontface = c(
+            1,
+            1
+          ),
+          lineheight = c(1.2, 1.2),
+          hjust = c(0.5, 0.5),
+          vjust = c(
+            0.5,
+            0.5
+          )
+        ),
+        row.names = c(NA, -2L),
+        class = "data.frame"
+      )
+    )
+
+    testthat::expect_equal(
+      pb1$data[[8]],
+      structure(
+        list(
+          x = 1:2,
+          y = c(7.86666666666667, 6.73888888888889),
+          group = structure(c(1L, 1L), n = 1L),
+          PANEL = structure(c(
+            1L,
+            1L
+          ), class = "factor", .Label = "1"),
+          colour = c("blue", "blue"),
+          size = c(2, 2),
+          linetype = c(1, 1),
+          alpha = c(0.8, 0.8)
+        ),
+        row.names = c(
+          NA,
+          -2L
+        ),
+        class = "data.frame"
+      )
+    )
+
     # data from difference layers
     testthat::expect_equal(max(pb1$data[[4]]$group), 90L)
 
@@ -90,56 +221,57 @@ testthat::test_that(
     library(WRS2)
 
     # plot
-    p1 <- ggstatsplot::ggwithinstats(
-      data = WineTasting,
-      x = Wine,
-      y = "Taste",
-      type = "p",
-      sort = "ascending",
-      sort.fun = median,
-      bf.message = TRUE,
-      k = 4,
-      conf.level = 0.99,
-      outlier.tagging = TRUE,
-      outlier.coef = 2.5,
-      pairwise.comparisons = TRUE,
-      pairwise.annotation = "asterisk",
-      title = "wine tasting data",
-      caption = "From `WRS2` package",
-      messages = TRUE
-    )
+    p1 <-
+      ggstatsplot::ggwithinstats(
+        data = WineTasting,
+        x = Wine,
+        y = "Taste",
+        type = "p",
+        sort = "ascending",
+        sort.fun = median,
+        bf.message = TRUE,
+        k = 4,
+        conf.level = 0.99,
+        outlier.tagging = TRUE,
+        outlier.coef = 2.5,
+        pairwise.comparisons = TRUE,
+        pairwise.annotation = "asterisk",
+        title = "wine tasting data",
+        caption = "From `WRS2` package",
+        messages = TRUE
+      )
 
     # build the plot
     pb1 <- ggplot2::ggplot_build(p1)
 
     # subtitle
     set.seed(123)
-    p1_subtitle <- statsExpressions::expr_anova_parametric(
-      data = WineTasting,
-      x = "Wine",
-      y = Taste,
-      type = "p",
-      k = 4,
-      paired = TRUE,
-      conf.level = 0.99,
-      messages = FALSE
-    )
+    p1_subtitle <-
+      statsExpressions::expr_anova_parametric(
+        data = WineTasting,
+        x = "Wine",
+        y = Taste,
+        type = "p",
+        k = 4,
+        paired = TRUE,
+        conf.level = 0.99,
+        messages = FALSE
+      )
 
     # dataframe used for visualization
     testthat::expect_equal(length(pb1$data), 8L)
     testthat::expect_equal(dim(pb1$data[[1]]), c(66L, 10L))
     testthat::expect_equal(dim(pb1$data[[2]]), c(3L, 25L))
     testthat::expect_equal(dim(pb1$data[[3]]), c(1536L, 20L))
-    # testthat::expect_equal(dim(pb1$data[[4]]), c(4L, 15L))
     testthat::expect_equal(dim(pb1$data[[5]]), c(3L, 12L))
-    # testthat::expect_equal(dim(pb1$data[[6]]), c(3L, 15L))
     testthat::expect_equal(dim(pb1$data[[7]]), c(3L, 8L))
     testthat::expect_equal(dim(pb1$data[[8]]), c(6L, 19L))
 
     # data from difference layers
     testthat::expect_equal(pb1$data[[5]]$x, c(1L, 2L, 3L))
-    testthat::expect_equal(pb1$data[[5]]$y,
-      c(5.459091, 5.543182, 5.53409),
+    testthat::expect_equal(
+      pb1$data[[5]]$y,
+      c(5.54318181818182, 5.53409090909091, 5.45909090909091),
       tolerance = 0.001
     )
 
@@ -160,7 +292,7 @@ testthat::test_that(
     # checking x-axis sample size labels
     testthat::expect_identical(
       ggplot2::layer_scales(p1)$x$labels,
-      c("Wine C\n(n = 22)", "Wine A\n(n = 22)", "Wine B\n(n = 22)")
+      c("Wine A\n(n = 22)", "Wine B\n(n = 22)", "Wine C\n(n = 22)")
     )
 
     # checking plot labels
@@ -195,7 +327,7 @@ testthat::test_that(
     testthat::expect_identical(p1$labels$y, "Taste")
 
     # checking pairwise comparisons
-    testthat::expect_equal(levels(pb1$data[[8]]$annotation), c("*", "**"))
+    # testthat::expect_equal(levels(pb1$data[[8]]$annotation), c("*", "**"))
 
     # caption for the plot
     set.seed(254)
@@ -207,7 +339,7 @@ testthat::test_that(
         messages = FALSE,
         bf.prior = 0.85,
         k = 3,
-        return = "caption"
+        output = "caption"
       )
 
     # function output
@@ -227,57 +359,6 @@ testthat::test_that(
   }
 )
 
-# checking sorting -------------------------------------------------------
-
-testthat::test_that(
-  desc = "checking sorting",
-  code = {
-    testthat::skip_on_cran()
-    set.seed(123)
-
-    # plot
-    p1 <- ggstatsplot::ggwithinstats(
-      data = WineTasting,
-      x = Wine,
-      y = Taste,
-      sort = "none",
-      package = "wesanderson",
-      palette = "Royal1",
-      results.subtitle = FALSE,
-      messages = FALSE
-    )
-
-    set.seed(123)
-    p2 <- ggstatsplot::ggwithinstats(
-      data = WineTasting,
-      x = Wine,
-      y = Taste,
-      sort = "ascending",
-      results.subtitle = FALSE,
-      messages = FALSE
-    )
-
-    set.seed(123)
-    p3 <- ggstatsplot::ggwithinstats(
-      data = WineTasting,
-      x = Wine,
-      y = Taste,
-      sort = "xxx",
-      results.subtitle = FALSE,
-      messages = FALSE
-    )
-
-    # built plots
-    pb1 <- ggplot2::ggplot_build(p1)
-    pb2 <- ggplot2::ggplot_build(p2)
-    pb3 <- ggplot2::ggplot_build(p3)
-
-    # tests
-    testthat::expect_equal(pb1$data[[6]]$label, rev(pb3$data[[6]]$label))
-    testthat::expect_equal(pb1$data[[6]]$label, pb2$data[[6]]$label)
-  }
-)
-
 # checking subtitle outputs - without NAs ------------------------------------
 
 testthat::test_that(
@@ -286,19 +367,19 @@ testthat::test_that(
     testthat::skip_on_cran()
     set.seed(123)
 
-    p1 <- ggstatsplot::ggwithinstats(
-      data = ggstatsplot::iris_long,
-      x = condition,
-      y = value,
-      type = "np",
-      pairwise.display = "s",
-      pairwise.annotation = "p",
-      outlier.tagging = FALSE,
-      pairwise.comparisons = TRUE,
-      axes.range.restrict = TRUE,
-      conf.level = 0.90,
-      messages = FALSE
-    )
+    p1 <-
+      ggstatsplot::ggwithinstats(
+        data = ggstatsplot::iris_long,
+        x = condition,
+        y = value,
+        type = "np",
+        pairwise.display = "s",
+        pairwise.annotation = "p",
+        outlier.tagging = FALSE,
+        pairwise.comparisons = TRUE,
+        conf.level = 0.90,
+        messages = FALSE
+      )
 
     set.seed(123)
     p1_subtitle <-
@@ -454,15 +535,15 @@ testthat::test_that(
     library(WRS2)
 
     # plot
-    p <- ggstatsplot::ggwithinstats(
-      data = WineTasting,
-      x = Wine,
-      y = Taste,
-      axes.range.restrict = TRUE,
-      results.subtitle = FALSE,
-      messages = FALSE,
-      ggplot.component = ggplot2::labs(y = "Taste rating")
-    )
+    p <-
+      ggstatsplot::ggwithinstats(
+        data = WineTasting,
+        x = Wine,
+        y = Taste,
+        results.subtitle = FALSE,
+        messages = FALSE,
+        ggplot.component = ggplot2::labs(y = "Taste rating")
+      )
 
     # build plot
     pb <- ggplot2::ggplot_build(p)
@@ -537,16 +618,17 @@ testthat::test_that(
 
     # capture the message
     set.seed(123)
-    p <- suppressWarnings(ggstatsplot::ggwithinstats(
-      data = df,
-      x = x,
-      y = y,
-      pairwise.display = "significant",
-      pairwise.annotation = "p.value",
-      pairwise.comparisons = TRUE,
-      sphericity.correction = TRUE,
-      messages = FALSE
-    ))
+    p <-
+      suppressWarnings(ggstatsplot::ggwithinstats(
+        data = df,
+        x = x,
+        y = y,
+        pairwise.display = "significant",
+        pairwise.annotation = "p.value",
+        pairwise.comparisons = TRUE,
+        sphericity.correction = TRUE,
+        messages = FALSE
+      ))
 
     # build the plot
     pb <- ggplot2::ggplot_build(p)
