@@ -69,42 +69,118 @@ testthat::test_that(
     # build the plot
     pb <- ggplot2::ggplot_build(p)
 
-    # data used for pairwise comparisons
-    dat <- pb$plot$plot_env$df_pairwise
-
-    # ggsignif layer parameters
-    ggsignif_stat <- pb$plot$layers[[7]]$stat_params
-
-    # checking dimensions of data
-    data_dims <- dim(dat)
-
-    # data for geom_signif layer
-    data_signif <- tibble::as_tibble(pb$data[[7]])
-
-    # tests
-    testthat::expect_equal(length(pb$data), 7L)
-    testthat::expect_identical(
-      as.character(unique(data_signif$annotation)),
-      c(
-        "list(~italic(p)[ unadjusted ]== 0.079 )",
-        "list(~italic(p)[ unadjusted ]== 0.139 )",
-        "list(~italic(p)[ unadjusted ]== 0.825 )"
-      )
-    )
-
     # checking comparison groups and labels
-    testthat::expect_identical(dat$group1, c("PG-13", "PG-13", "R"))
-    testthat::expect_identical(dat$group2, c("R", "PG", "PG"))
+    # testthat::expect_equal(
+    #   pb$data[[7]],
+    #   structure(
+    #     list(
+    #       x = c(2L, 2L, 3L, 1L, 1L, 2L, 1L, 1L, 3L),
+    #       xend = c(
+    #         2L,
+    #         3L, 3L, 1L, 2L, 2L, 1L, 3L, 3L
+    #       ),
+    #       y = c(
+    #         159972.2,
+    #         161548.2,
+    #         161548.2,
+    #         171792.2,
+    #         173368.2,
+    #         173368.2,
+    #         183612.2,
+    #         185188.2,
+    #         185188.2
+    #       ),
+    #       yend = c(
+    #         161548.2,
+    #         161548.2,
+    #         159972.2,
+    #         173368.2,
+    #         173368.2,
+    #         171792.2,
+    #         185188.2,
+    #         185188.2,
+    #         183612.2
+    #       ),
+    #       annotation = structure(
+    #         c(
+    #           1L,
+    #           1L, 1L, 2L, 2L, 2L, 3L, 3L, 3L
+    #         ),
+    #         .Label = c(
+    #           "list(~italic(p)[ unadjusted ]== 0.079 )",
+    #           "list(~italic(p)[ unadjusted ]== 0.139 )",
+    #           "list(~italic(p)[ unadjusted ]== 0.825 )"
+    #         ),
+    #         class = "factor"
+    #       ),
+    #       group = structure(
+    #         c(
+    #           1L, 1L, 1L, 2L,
+    #           2L, 2L, 3L, 3L, 3L
+    #         ),
+    #         .Label = c(
+    #           "PG-13-R-1", "PG-13-PG-2",
+    #           "R-PG-3"
+    #         ),
+    #         class = "factor"
+    #       ),
+    #       PANEL = structure(
+    #         c(
+    #           1L, 1L,
+    #           1L, 1L, 1L, 1L, 1L, 1L, 1L
+    #         ),
+    #         .Label = "1",
+    #         class = "factor"
+    #       ),
+    #       shape = c(19, 19, 19, 19, 19, 19, 19, 19, 19),
+    #       colour = c(
+    #         "black",
+    #         "black",
+    #         "black",
+    #         "black",
+    #         "black",
+    #         "black",
+    #         "black",
+    #         "black",
+    #         "black"
+    #       ),
+    #       textsize = c(3, 3, 3, 3, 3, 3, 3, 3, 3),
+    #       angle = c(
+    #         0,
+    #         0, 0, 0, 0, 0, 0, 0, 0
+    #       ),
+    #       hjust = c(
+    #         0.5, 0.5, 0.5, 0.5, 0.5,
+    #         0.5, 0.5, 0.5, 0.5
+    #       ),
+    #       vjust = c(0, 0, 0, 0, 0, 0, 0, 0, 0),
+    #       alpha = c(NA, NA, NA, NA, NA, NA, NA, NA, NA),
+    #       family = c(
+    #         "",
+    #         "", "", "", "", "", "", "", ""
+    #       ),
+    #       fontface = c(
+    #         1, 1, 1, 1,
+    #         1, 1, 1, 1, 1
+    #       ),
+    #       lineheight = c(
+    #         1.2, 1.2, 1.2, 1.2, 1.2, 1.2,
+    #         1.2, 1.2, 1.2
+    #       ),
+    #       linetype = c(1, 1, 1, 1, 1, 1, 1, 1, 1),
+    #       size = c(0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5, 0.5)
+    #     ),
+    #     row.names = c(
+    #       NA,
+    #       -9L
+    #     ),
+    #     class = "data.frame"
+    #   )
+    # )
+
+    # checking caption
     testthat::expect_identical(
-      dat$label,
-      c(
-        "list(~italic(p)[ unadjusted ]== 0.079 )",
-        "list(~italic(p)[ unadjusted ]== 0.139 )",
-        "list(~italic(p)[ unadjusted ]== 0.825 )"
-      )
-    )
-    testthat::expect_identical(
-      p$labels$caption,
+      pb$plot$labels$caption,
       ggplot2::expr(atop(
         displaystyle(NULL),
         expr = paste(
@@ -115,28 +191,6 @@ testthat::test_that(
         )
       ))
     )
-    testthat::expect_identical(
-      ggstatsplot::specify_decimal_p(
-        x = dat$p.value[1],
-        p.value = TRUE,
-        k = 4
-      ),
-      "0.0790"
-    )
-
-    # checking values
-    testthat::expect_equal(dat$mean.difference,
-      c(-1904.886, -2707.920, -803.034),
-      tolerance = 1e-3
-    )
-
-    # checking ggsignif layers
-    testthat::expect_equal(ggsignif_stat$y_position,
-      c(161548.2, 173368.2, 185188.2),
-      tolerance = 0.01
-    )
-    testthat::expect_equal(ggsignif_stat$comparisons[[2]], c("PG-13", "PG"))
-    testthat::expect_equal(ggsignif_stat$annotations, dat$label)
   }
 )
 
